@@ -73,7 +73,6 @@ if (        exists $parser->YYData->{root}
 	$parser->YYData->{root}->visit(new CORBA::JAVA::nameVisitor($parser, $parser->YYData->{opt_p}, $parser->YYData->{opt_t}));
 	$parser->YYData->{root}->visit(new CORBA::JAVA::literalVisitor($parser));
 	$parser->YYData->{root}->visit(new CORBA::JAVA::name2Visitor($parser));
-#	$parser->YYData->{symbtab}->Export();		##
 	$parser->YYData->{root}->visit(new CORBA::JAVA::classVisitor($parser));
 }
 
@@ -147,8 +146,8 @@ The parser is generated by Parse::Yapp.
 
 B<idl2java> needs a B<cpp> executable.
 
-CORBA Specifications, including IDL (Interface Definition Language) are
-available on E<lt>http://www.omg.org/E<gt>.
+CORBA Specifications, including IDL (Interface Language Definition) and
+JAVA Language Mapping are available on E<lt>http://www.omg.org/E<gt>.
 
 =head1 SEE ALSO
 
